# Welcome to the Recipe Tool Codespace

The steps below will help you get started with Recipe Tool.

## How to use

See the [README](../README.md) for more details on how to use Recipe Tool.

### Connecting to the Codespace in the future

- Launch VS Code and open the command palette with the `F1` key or `Ctrl/Cmd+Shift+P`
- Type `Codespaces: Connect to Codespace...` and select it
- After the Codespace is ready, you will be prompted to open the workspace; click `Open Workspace`

### Optimizing your Codespaces experience

See [OPTIMIZING_FOR_CODESPACES.md](./OPTIMIZING_FOR_CODESPACES.md) for tips on optimizing your Codespaces experience.

## Deleting a Codespace

When you are done with a Codespace, you can delete it to free up resources.

- Visit the source repository on GitHub
- Click on the `Code` button and select the Codespaces tab
- Click on the `...` button next to the Codespace you want to delete
- Select `Delete`
